@@ -18,6 +18,8 @@
 /*
 ISSUES:
     - Do the drawing in thread and show the progress
+    - Maemo doesn't show busybar
+    - Cancelling shows random files
 */
 
 #include <QtGui/QApplication>
@@ -33,8 +35,8 @@ int main(int argc, char *argv[])
     QApplication a(argc, argv);
     CMainWindow w;
 
-    a.setApplicationName("diskusage");
-    w.intialize();
+    a.setApplicationName("storageusage");
+    w.initialize();
 
 #ifndef Q_WS_HILDON
     w.resize(800, 480);
