@@ -87,7 +87,7 @@ void CScanThread::run()
 
     emit progressValue(QString(), -1);
 
-    qDebug() << "Total scan time: " << timer.elapsed();
+    // qDebug() << "Total scan time: " << timer.elapsed();
 }
 
 //-----------------------------------------------------------------------------
@@ -98,7 +98,7 @@ void CScanThread::run()
 */
 void CScanThread::scanFolder(const QString& strFolder)
 {
-    emit progressMaximum(0);        // Show busybar
+    emit progressMaximum(1);
 
     QDir dir(strFolder);
     dir.setFilter(QDir::Files | QDir::Dirs | QDir::Hidden | QDir::NoSymLinks | QDir::NoDotAndDotDot);
@@ -110,6 +110,8 @@ void CScanThread::scanFolder(const QString& strFolder)
 
         if (fileInfo.isDir())
         {
+            emit progressValue(fileInfo.baseName(), 0);
+
             emit folderFound(fileInfo.absoluteFilePath());
 
             //qDebug() << fileInfo.absoluteFilePath();
@@ -153,9 +155,16 @@ void CScanThread::scanInstallations()
 
         QFileInfo fileInfo = list.at(i);
 
-        emit progressValue(fileInfo.baseName(), count++);
+        QString strBase = fileInfo.fileName();
+        int pos = strBase.lastIndexOf('.');
+        if (pos != -1)
+        {
+            strBase = strBase.left(pos);
+        }
 
-        emit folderFound(fileInfo.baseName());
+        emit progressValue(strBase, 0 /*count++*/);         // Qt in Maemo has a bug which hides the text if the progress is shown
+
+        emit folderFound(strBase);
         readPackageFiles(fileInfo.absoluteFilePath());
         emit folderScanned();
     }
@@ -173,16 +182,11 @@ void CScanThread::readPackageFiles(QString strPackage)
     QFile file(strPackage);
     if (file.open(QFile::ReadOnly))
     {
-        QByteArray arrayData = file.readAll();
-        QList<QByteArray> listLines = arrayData.split('\n');
+        QString arrayData = file.readAll();
+        QList<QString> listLines = arrayData.split('\n');
         for (int i = 0; i < listLines.size(); i++)
         {
-            if (isCancelled())
-            {
-                break;
-            }
-
-            QByteArray array = listLines[i];
+            QString array = listLines[i];
             // This is a folder if the next line has the same beginning
             if (i + 1 < listLines.size())
             {
