@@ -155,7 +155,7 @@ void CUsageGrid::createGrid(QStandardItem* pItem, bool bRecursive)
     painter.setFont(font);
     drawGrid(painter, pItem, rect(), bRecursive);
 
-    qDebug() << "Create grid time: " << timer.elapsed();
+    // qDebug() << "Create grid time: " << timer.elapsed();
 }
 
 //-----------------------------------------------------------------------------
